@@ -346,7 +346,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             return fail!("dynfmt/calcconv subcommand requires headers.");
         }
         // first, get the fields used in the dynfmt template
-        let (safe_headers, _) = util::safe_header_names(&headers, false, false, None, "");
+        let (safe_headers, _) = util::safe_header_names(&headers, false, false, None, "", true);
         let formatstr_re: &'static Regex = crate::regex_oncelock!(r"\{(?P<key>\w+)?\}");
         for format_fields in formatstr_re.captures_iter(&args.flag_formatstr) {
             dynfmt_fields.push(format_fields.name("key").unwrap().as_str());
@@ -354,7 +354,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         // we sort the fields so we can do binary_search
         dynfmt_fields.sort_unstable();
         // now, get the indices of the columns for the lookup vec
-        for (i, field) in safe_headers.into_iter().enumerate() {
+        for (i, field) in safe_headers.iter().enumerate() {
             if dynfmt_fields.binary_search(&field.as_str()).is_ok() {
                 let field_with_curly = format!("{{{field}}}");
                 let field_index = format!("{{{i}}}");
