@@ -18,6 +18,8 @@ By default, it will connect to a local Redis instance at redis://127.0.0.1:6379/
 with a cache expiry Time-to-Live (TTL) of 2,419,200 seconds (28 days),
 and cache hits NOT refreshing the TTL of cached values.
 
+If you don't want responses to be cached, use the --no-cache flag.
+
 Set the environment variables QSV_REDIS_CONNSTR, QSV_REDIS_TTL_SECONDS and 
 QSV_REDIS_TTL_REFRESH to change default Redis settings.
 
@@ -142,12 +144,13 @@ Fetch options:
                                Set to zero (0) to continue despite errors.
                                [default: 10 ]
     --store-error              On error, store error code/message instead of blank value.
+    --no-cache                 Do not cache responses.
     --cache-error              Cache error responses even if a request fails. If an identical URL is requested,
                                the cached error is returned. Otherwise, the fetch is attempted again 
                                for --max-retries.
     --cookies                  Allow cookies.
     --user-agent <agent>       Specify custom user agent. It supports the following variables -
-                               $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME and $QSV_KIND. 
+                               $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME, $QSV_KIND and $QSV_COMMAND.
                                Try to follow the syntax here -
                                https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/User-Agent
     --report <d|s>             Creates a report of the fetch job. The report has the same name as the input file
@@ -228,6 +231,7 @@ struct Args {
     flag_max_retries:  u8,
     flag_max_errors:   u64,
     flag_store_error:  bool,
+    flag_no_cache:     bool,
     flag_cache_error:  bool,
     flag_cookies:      bool,
     flag_user_agent:   Option<String>,
@@ -266,11 +270,6 @@ enum ReportKind {
     None,
 }
 
-impl From<reqwest::Error> for CliError {
-    fn from(err: reqwest::Error) -> CliError {
-        CliError::Other(err.to_string())
-    }
-}
 #[derive(Debug)]
 struct RedisConfig {
     conn_str:      String,
@@ -393,7 +392,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         dynfmt_url_template = url_template.to_string();
         // first, get the fields used in the url template
-        let (safe_headers, _) = util::safe_header_names(&str_headers, false, false, None, "");
+        let (safe_headers, _) =
+            util::safe_header_names(&str_headers, false, false, None, "", false);
         let formatstr_re: &'static Regex = regex_oncelock!(r"\{(?P<key>\w+)?\}");
         for format_fields in formatstr_re.captures_iter(url_template) {
             dynfmt_fields.push(format_fields.name("key").unwrap().as_str());
@@ -401,7 +401,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         // we sort the fields so we can do binary_search
         dynfmt_fields.sort_unstable();
         // now, get the indices of the columns for the lookup vec
-        for (i, field) in safe_headers.into_iter().enumerate() {
+        for (i, field) in safe_headers.iter().enumerate() {
             if dynfmt_fields.binary_search(&field.as_str()).is_ok() {
                 let field_with_curly = format!("{{{field}}}");
                 let field_index = format!("{{{i}}}");
@@ -632,7 +632,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         if url.is_empty() {
             final_response.clone_from(&empty_response);
             was_cached = false;
-        } else if args.flag_redis {
+        } else if args.flag_redis && !args.flag_no_cache {
             intermediate_redis_value = get_redis_response(
                 &url,
                 &client,
@@ -671,6 +671,18 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     wwarn!(r#"Cannot remove Redis key "{key}""#);
                 };
             }
+        } else if args.flag_no_cache {
+            final_response = get_response(
+                &url,
+                &client,
+                &limiter,
+                &jql_selector,
+                args.flag_store_error,
+                args.flag_pretty,
+                include_existing_columns,
+                args.flag_max_retries,
+            );
+            was_cached = false;
         } else {
             intermediate_value = get_cached_response(
                 &url,
