@@ -22,6 +22,8 @@ and cache hits NOT refreshing the TTL of cached values.
 Note that the default values are the same as the fetch command, except fetchpost creates the
 cache at database 2, as opposed to database 1 with fetch.
 
+If you don't want responses to be cached, use the --no-cache flag.
+
 Set the environment variables QSV_FP_REDIS_CONNSTR, QSV_FP_REDIS_TTL_SECONDS and 
 QSV_FP_REDIS_TTL_REFRESH respectively to change default Redis settings.
 
@@ -133,12 +135,13 @@ Fetchpost options:
                                Set to zero (0) to continue despite errors.
                                [default: 10 ]
     --store-error              On error, store error code/message instead of blank value.
+    --no-cache                 Do not cache responses.
     --cache-error              Cache error responses even if a request fails. If an identical URL is requested,
                                the cached error is returned. Otherwise, the fetch is attempted again
                                for --max-retries.
     --cookies                  Allow cookies.
     --user-agent <agent>       Specify custom user agent. It supports the following variables -
-                               $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME and $QSV_KIND. 
+                               $QSV_VERSION, $QSV_TARGET, $QSV_BIN_NAME, $QSV_KIND and $QSV_COMMAND.
                                Try to follow the syntax here -
                                https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/User-Agent
     --report <d|s>             Creates a report of the fetchpost job. The report has the same name as the
@@ -220,6 +223,7 @@ struct Args {
     flag_max_retries: u8,
     flag_max_errors:  u64,
     flag_store_error: bool,
+    flag_no_cache:    bool,
     flag_cache_error: bool,
     flag_cookies:     bool,
     flag_user_agent:  Option<String>,
@@ -602,7 +606,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         // construct body per the column-list
         form_body_jsonmap.clear();
-        for col_idx in col_list.iter() {
+        for col_idx in &*col_list {
             let header_key = String::from_utf8_lossy(headers.get(*col_idx).unwrap());
             let value_string = from_utf8(&record[*col_idx]).unwrap_or_default().to_string();
             form_body_jsonmap.insert(
@@ -625,7 +629,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         if url.is_empty() {
             final_response.clone_from(&empty_response);
             was_cached = false;
-        } else if args.flag_redis {
+        } else if args.flag_redis && !args.flag_no_cache {
             intermediate_redis_value = get_redis_response(
                 &url,
                 &form_body_jsonmap,
@@ -668,6 +672,20 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     wwarn!(r#"Cannot remove Redis key "{key}""#);
                 };
             }
+        } else if args.flag_no_cache {
+            final_response = get_response(
+                &url,
+                &form_body_jsonmap,
+                &client,
+                &limiter,
+                &jql_selector,
+                args.flag_store_error,
+                args.flag_pretty,
+                args.flag_compress,
+                include_existing_columns,
+                args.flag_max_retries,
+            );
+            was_cached = false;
         } else {
             intermediate_value = get_cached_response(
                 &url,
