@@ -687,8 +687,7 @@ fn sequential_mode(
 
         // Updating col
         {
-            let col =
-                luau.create_table_with_capacity(record.len().try_into().unwrap_or_default(), 1)?;
+            let col = luau.create_table_with_capacity(record.len(), 1)?;
 
             for (i, v) in record.iter().enumerate() {
                 col.set(i + 1, v)?;
@@ -877,7 +876,9 @@ fn random_access_mode(
 
     // we abort RANDOM ACCESS mode if the index file is not found
     let Some(mut idx_file) = rconfig.indexed()? else {
-        return fail!(r#"Index required but no index file found. Use "qsv_autoindex()" in your BEGIN script."#); 
+        return fail!(
+            r#"Index required but no index file found. Use "qsv_autoindex()" in your BEGIN script."#
+        );
     };
 
     globals.set("cols", "{}")?;
@@ -1024,8 +1025,7 @@ fn random_access_mode(
 
         processed_count += 1;
         {
-            let col =
-                luau.create_table_with_capacity(record.len().try_into().unwrap_or_default(), 1)?;
+            let col = luau.create_table_with_capacity(record.len(), 1)?;
 
             for (i, v) in record.iter().enumerate() {
                 col.set(i + 1, v)?;
@@ -1284,7 +1284,7 @@ fn create_insertrecord(
 ) -> Result<(), CliError> {
     let mut columns_inserted = 0_usize;
 
-    for v in insertrecord_table.clone().raw_sequence_values::<String>() {
+    for v in insertrecord_table.clone().sequence_values::<String>() {
         let v = v?;
         insertrecord.push_field(&v);
 
@@ -1335,7 +1335,7 @@ fn beginend_insertrecord(
 fn create_index(arg_input: &Option<String>) -> Result<bool, CliError> {
     // this is a utility function that creates an index file for the current CSV.
     // it is called when "qsv_autoindex()" is called in the BEGIN script.
-    let Some(input ) = &arg_input else {
+    let Some(input) = &arg_input else {
         log::warn!("qsv_autoindex() does not work for stdin.");
         return Ok(false);
     };
@@ -1783,8 +1783,7 @@ fn setup_helpers(
     //      returns: None. Will always succeed.
     //
     let qsv_insertrecord = luau.create_function(|luau, mut args: mlua::MultiValue| {
-        let args_len = args.len().try_into().unwrap_or(10_i32);
-        let insertrecord_table = luau.create_table_with_capacity(args_len, 1)?;
+        let insertrecord_table = luau.create_table_with_capacity(args.len(), 1)?;
         // Luau tables are 1-based
         let mut idx = 1_u16;
 
@@ -1909,10 +1908,12 @@ fn setup_helpers(
 
         let shellcmd_string = shellcmd.to_ascii_lowercase();
         let Ok(_) = ShellCmd::from_str(&shellcmd_string) else {
-            return helper_err!("qsv_shellcmd", "Invalid shell command: \"{shellcmd}\". \
-                Only the following commands are allowed: \
-                awk, cat, cp, cut, df, echo, rg, grep, head, ls, mkdir, \
-                mv, nl, pwd, sed, sort, tail, touch, tr, uname, uniq, wc, whoami")
+            return helper_err!(
+                "qsv_shellcmd",
+                "Invalid shell command: \"{shellcmd}\". Only the following commands are allowed: \
+                 awk, cat, cp, cut, df, echo, rg, grep, head, ls, mkdir, mv, nl, pwd, sed, sort, \
+                 tail, touch, tr, uname, uniq, wc, whoami"
+            );
         };
 
         let args_string = args.as_str().to_string();
