@@ -24,11 +24,34 @@ Example queries:
 
   qsv sqlp data.csv 'SELECT col1, count(*) AS cnt FROM data GROUP BY col1 ORDER BY cnt DESC, col1 ASC'
 
-  qsv sqlp data.csv data2.csv script.sql --format json --output data.json
+  qsv sqlp data.csv data2.csv data3.csv data4.csv script.sql --format json --output data.json
 
-  qsv sqlp data.csv "select col1, col2, col3 from data WHERE col1 = 'foo' AND col2 > 10"
+  qsv sqlp data.csv "select lower(col1), substr(col2, 2, 4) from data WHERE starts_with(col1, 'foo')"
 
-  qsv sqlp data.csv "select data.col1, tbl2.col1 from data join read_parquet('data2.parquet') as tbl2 ON data.col1 = tbl2.col1"
+  # spaceship operator: "<=>" (three-way comparison operator)
+  #  returns -1 if left < right, 0 if left == right, 1 if left > right
+  # https://en.wikipedia.org/wiki/Three-way_comparison#Spaceship_operator
+  qsv sqlp data.csv data2.csv "select data.col2 <=> data2.col2 from data join data2 on data.col1 = data2.col1"
+
+  # regex operators: "~" (contains pattern, case-sensitive); "~*" (contains pattern, case-insensitive)
+  #   "!~" (does not contain pattern, case-sensitive); "!~*" (does not contain pattern, case-insensitive)
+    qsv sqlp data.csv "select * from data WHERE col1 ~ '^foo' AND col2 > 10"
+    qsv sqlp data.csv "select * from data WHERE col1 !~* 'bar$' AND col2 > 10"
+
+  # regexp_like function: regexp_like(<string>, <pattern>, <optional flags>)
+  # returns true if <string> matches <pattern>, false otherwise
+  #   <optional flags> can be one or more of the following:
+  #   'c' (case-sensitive - default), 'i' (case-insensitive), 'm' (multiline)
+  qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo') AND col2 > 10"
+  # case-insensitive regexp_like
+  qsv sqlp data.csv "select * from data WHERE regexp_like(col1, '^foo', 'i') AND col2 > 10"
+
+  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_parquet('data2.parquet') as t2 ON data.col1 = t2.col1"
+  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_ndjson('data2.jsonl') as t2 on data.col1 = t2.col1"
+  qsv sqlp data.csv "select data.col1, t2.col1 from data join read_ipc('data2.arrow') as t2 ON data.col1 = t2.col1"
+
+  cat data.csv | qsv sqlp - 'select * from stdin'
+  cat data.csv | qsv sqlp - data2.csv 'select * from stdin join data2 on stdin.col1 = data2.col1'
 
 For more examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_sqlp.rs.
 
@@ -63,12 +86,12 @@ sqlp options:
                               POLARS CSV PARSING OPTIONS:
     --try-parsedates          Automatically try to parse dates/datetimes and time.
                               If parsing fails, columns remain as strings.
-    --infer-schema-len <arg>  The number of rows to scan when inferring the schema of the CSV.
+    --infer-len <arg>         The number of rows to scan when inferring the schema of the CSV.
                               Set to 0 to do a full table scan (warning: very slow).
                               (default: 250)
     --low-memory              Use low memory mode when parsing CSVs. This will use less memory
                               but will be slower. It will also process LazyFrames in streaming mode.
-                              Only use this in memory constrained environments.
+                              Only use this when you get out of memory errors.
     --ignore-errors           Ignore errors when parsing CSVs. If set, rows with errors
                               will be skipped. If not set, the query will fail.
                               Only use this when debugging queries, as polars does batched
@@ -114,7 +137,6 @@ use std::{
     io,
     io::{BufWriter, Read, Write},
     path::{Path, PathBuf},
-    str,
     str::FromStr,
     time::Instant,
 };
@@ -140,29 +162,29 @@ use crate::{
 static DEFAULT_GZIP_COMPRESSION_LEVEL: u8 = 6;
 static DEFAULT_ZSTD_COMPRESSION_LEVEL: i32 = 3;
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Deserialize, Clone)]
 struct Args {
-    arg_input:             Vec<PathBuf>,
-    arg_sql:               String,
-    flag_format:           String,
-    flag_try_parsedates:   bool,
-    flag_infer_schema_len: usize,
-    flag_low_memory:       bool,
-    flag_ignore_errors:    bool,
-    flag_datetime_format:  Option<String>,
-    flag_date_format:      Option<String>,
-    flag_time_format:      Option<String>,
-    flag_float_precision:  Option<usize>,
-    flag_null_value:       String,
-    flag_compression:      String,
-    flag_compress_level:   Option<i32>,
-    flag_statistics:       bool,
-    flag_output:           Option<String>,
-    flag_delimiter:        Option<Delimiter>,
-    flag_quiet:            bool,
+    arg_input:            Vec<PathBuf>,
+    arg_sql:              String,
+    flag_format:          String,
+    flag_try_parsedates:  bool,
+    flag_infer_len:       usize,
+    flag_low_memory:      bool,
+    flag_ignore_errors:   bool,
+    flag_datetime_format: Option<String>,
+    flag_date_format:     Option<String>,
+    flag_time_format:     Option<String>,
+    flag_float_precision: Option<usize>,
+    flag_null_value:      String,
+    flag_compression:     String,
+    flag_compress_level:  Option<i32>,
+    flag_statistics:      bool,
+    flag_output:          Option<String>,
+    flag_delimiter:       Option<Delimiter>,
+    flag_quiet:           bool,
 }
 
-#[derive(Debug, Default, Clone)]
+#[derive(Default, Clone)]
 enum OutputMode {
     #[default]
     Csv,
@@ -275,7 +297,7 @@ impl FromStr for OutputMode {
     }
 }
 
-#[derive(Debug, Default, Copy, Clone)]
+#[derive(Default, Copy, Clone)]
 enum PqtCompression {
     Uncompressed,
     Gzip,
@@ -325,10 +347,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         b','
     };
 
-    let num_rows = if args.flag_infer_schema_len == 0 {
+    let num_rows = if args.flag_infer_len == 0 {
         None
     } else {
-        Some(args.flag_infer_schema_len)
+        Some(args.flag_infer_len)
     };
 
     let optimize_all = polars::lazy::frame::OptState {
@@ -356,7 +378,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 lossy_table_name = table.to_string_lossy();
                 &lossy_table_name
             });
-
         table_aliases.insert(table_name.to_string(), format!("_t_{}", idx + 1));
 
         if log::log_enabled!(log::Level::Debug) {
@@ -364,16 +385,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 "Registering table: {table_name} as {alias} -  Delimiter: {delim} \
                  Infer_schema_len: {num_rows:?} try_parse_dates: {parse_dates} ignore_errors: \
                  {ignore_errors}, low_memory: {low_memory}",
-                table_name = table_name,
                 alias = table_aliases.get(table_name).unwrap(),
-                delim = delim,
-                num_rows = num_rows,
                 parse_dates = args.flag_try_parsedates,
                 ignore_errors = args.flag_ignore_errors,
                 low_memory = args.flag_low_memory
             );
         }
-
         let lf = LazyCsvReader::new(table)
             .has_header(true)
             .with_missing_is_null(true)
@@ -383,7 +400,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             .with_ignore_errors(args.flag_ignore_errors)
             .low_memory(args.flag_low_memory)
             .finish()?;
-
         ctx.register(table_name, lf.with_optimizations(optimize_all));
     }
 
