@@ -336,13 +336,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             .keep()
             .or(Err("Cannot keep temporary file".to_string()))?;
         stdin_tempfile_path = Some(tempfile_path.clone());
-        args.arg_input = Some(
-            tempfile_path
-                .as_os_str()
-                .to_os_string()
-                .into_string()
-                .unwrap(),
-        );
+        args.arg_input = Some(tempfile_path.to_string_lossy().to_string());
         fconfig.path = Some(tempfile_path);
     } else {
         // check if the input file exists
@@ -489,7 +483,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             let stats_sr_vec = args.stats_to_records(stats);
 
             wtr.write_record(&args.stat_headers())?;
-            let fields = headers.iter().zip(stats_sr_vec.into_iter());
+            let fields = headers.iter().zip(stats_sr_vec);
             for (i, (header, stat)) in fields.enumerate() {
                 let header = if args.flag_no_headers {
                     i.to_string().into_bytes()
