@@ -42,7 +42,7 @@ extern crate qsv_docopt as docopt;
 use docopt::Docopt;
 use serde::Deserialize;
 
-use crate::clitypes::{CliError, CliResult, QsvExitCode};
+use crate::clitypes::{CliError, CliResult, QsvExitCode, CURRENT_COMMAND};
 
 #[cfg(feature = "mimalloc")]
 #[global_allocator]
@@ -97,6 +97,7 @@ fn main() -> QsvExitCode {
     cat         Concatenate by row or column
     count       Count records
     dedup       Remove redundant rows
+    describegpt Infer extended metadata using a LLM
     diff        Find the difference between two CSVs
     enum        Add a new column enumerating CSV lines
     excel       Exports an Excel sheet to a CSV
@@ -288,6 +289,7 @@ enum Command {
     Cat,
     Count,
     Dedup,
+    Describegpt,
     Diff,
     Enum,
     Excel,
@@ -360,6 +362,8 @@ impl Command {
                 argv[1].to_lowercase()
             )));
         }
+
+        CURRENT_COMMAND.get_or_init(|| argv[1].to_lowercase());
         match self {
             Command::Behead => cmd::behead::run(argv),
             #[cfg(all(feature = "apply", feature = "feature_capable"))]
@@ -367,6 +371,7 @@ impl Command {
             Command::Cat => cmd::cat::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
+            Command::Describegpt => cmd::describegpt::run(argv),
             Command::Diff => cmd::diff::run(argv),
             Command::Enum => cmd::enumerate::run(argv),
             Command::Excel => cmd::excel::run(argv),
