@@ -40,7 +40,7 @@ extern crate qsv_docopt as docopt;
 use docopt::Docopt;
 use serde::Deserialize;
 
-use crate::clitypes::{CliError, CliResult, QsvExitCode};
+use crate::clitypes::{CliError, CliResult, QsvExitCode, CURRENT_COMMAND};
 
 #[cfg(feature = "mimalloc")]
 #[global_allocator]
@@ -55,6 +55,7 @@ macro_rules! command_list {
         "
     applydp     Apply series of transformations to a column
     count       Count records
+    describegpt Infer extended metadata using a LLM
     diff        Find the difference between two CSVs
     dedup       Remove redundant rows
     excel       Exports an Excel sheet to a CSV
@@ -211,6 +212,7 @@ enum Command {
     ApplyDP,
     Count,
     Dedup,
+    Describegpt,
     Diff,
     Excel,
     Exclude,
@@ -251,10 +253,12 @@ impl Command {
                 argv[1].to_lowercase()
             )));
         }
+        CURRENT_COMMAND.get_or_init(|| argv[1].to_lowercase());
         match self {
             Command::ApplyDP => cmd::applydp::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
+            Command::Describegpt => cmd::describegpt::run(argv),
             Command::Diff => cmd::diff::run(argv),
             Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
