@@ -5,7 +5,7 @@ extern crate qsv_docopt as docopt;
 use docopt::Docopt;
 use serde::Deserialize;
 
-use crate::clitypes::{CliError, CliResult, QsvExitCode};
+use crate::clitypes::{CliError, CliResult, QsvExitCode, CURRENT_COMMAND};
 
 #[cfg(feature = "mimalloc")]
 #[global_allocator]
@@ -22,6 +22,7 @@ macro_rules! command_list {
     cat         Concatenate by row or column
     count       Count records
     dedup       Remove redundant rows
+    describegpt Infer extended metadata using a LLM
     diff        Find the difference between two CSVs
     enum        Add a new column enumerating CSV lines
     excel       Exports an Excel sheet to a CSV
@@ -192,6 +193,7 @@ enum Command {
     Cat,
     Count,
     Dedup,
+    Describegpt,
     Diff,
     Enum,
     Excel,
@@ -246,12 +248,14 @@ impl Command {
                 argv[1].to_lowercase()
             )));
         }
+        CURRENT_COMMAND.get_or_init(|| argv[1].to_lowercase());
         match self {
             Command::Behead => cmd::behead::run(argv),
             Command::Cat => cmd::cat::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Diff => cmd::diff::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
+            Command::Describegpt => cmd::describegpt::run(argv),
             Command::Enum => cmd::enumerate::run(argv),
             Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
