@@ -49,7 +49,7 @@ impl SelectColumns {
         let mut map = vec![];
         for sel in &self.selectors {
             let idxs = sel.indices(first_record, use_names);
-            map.extend(idxs?.into_iter());
+            map.extend(idxs?);
         }
         if self.invert {
             let set: HashSet<_> = map.into_iter().collect();
@@ -106,7 +106,9 @@ impl SelectorParser {
                 return fail_format!("Empty regex: {}", self.chars.iter().collect::<String>());
             }
             let re: String = self.chars[1..(self.chars.len() - 1)].iter().collect();
-            let Ok(regex) = Regex::new(&re) else { return fail_format!("Invalid regex: {re}") };
+            let Ok(regex) = Regex::new(&re) else {
+                return fail_format!("Invalid regex: {re}");
+            };
             return Ok(vec![Selector::Regex(regex)]);
         }
 
