@@ -23,7 +23,7 @@ use sysinfo::{System, SystemExt};
 use crate::{
     config,
     config::{Config, Delimiter},
-    CliError, CliResult,
+    CliError, CliResult, CURRENT_COMMAND,
 };
 
 #[macro_export]
@@ -59,7 +59,9 @@ const QSV_KIND: &str = match option_env!("QSV_KIND") {
 };
 
 fn default_user_agent() -> String {
-    format!("{CARGO_BIN_NAME}/{CARGO_PKG_VERSION} ({TARGET}; {QSV_KIND}; https://github.com/jqnatividad/qsv)")
+    let unknown_command = "Unknown".to_string();
+    let current_command = CURRENT_COMMAND.get().unwrap_or(&unknown_command);
+    format!("{CARGO_BIN_NAME}/{CARGO_PKG_VERSION} ({TARGET}; {current_command}; {QSV_KIND}; https://github.com/jqnatividad/qsv)")
 }
 
 pub fn max_jobs() -> usize {
@@ -107,8 +109,8 @@ pub fn timeout_secs(timeout: u16) -> Result<u64, String> {
 
 /// sets custom user agent
 /// if user agent is not set, then use the default user agent
-/// it supports four special LITERALs: $QSV_BIN_NAME, $QSV_VERSION, $QSV_TARGET, and $QSV_KIND
-/// which will be replaced with the actual values during runtime
+/// it supports four special LITERALs: $QSV_BIN_NAME, $QSV_VERSION, $QSV_TARGET, $QSV_KIND
+/// and $QSV_COMMAND which will be replaced with the actual values during runtime
 pub fn set_user_agent(user_agent: Option<String>) -> CliResult<String> {
     use reqwest::header::HeaderValue;
 
@@ -117,12 +119,16 @@ pub fn set_user_agent(user_agent: Option<String>) -> CliResult<String> {
         None => env::var("QSV_USER_AGENT").unwrap_or_else(|_| default_user_agent()),
     };
 
+    let unknown_command = "Unknown".to_string();
+    let current_command = CURRENT_COMMAND.get().unwrap_or(&unknown_command);
+
     // look for special literals - $QSV_VERSION and $QSV_TARGET and replace them
     let ua = ua
         .replace("$QSV_BIN_NAME", CARGO_BIN_NAME)
         .replace("$QSV_VERSION", CARGO_PKG_VERSION)
         .replace("$QSV_TARGET", TARGET)
-        .replace("$QSV_KIND", QSV_KIND);
+        .replace("$QSV_KIND", QSV_KIND)
+        .replace("$QSV_COMMAND", current_command);
 
     match HeaderValue::from_str(ua.as_str()) {
         Ok(_) => (),
@@ -176,7 +182,7 @@ pub fn version() -> String {
     #[cfg(all(feature = "to", not(feature = "lite")))]
     enabled_features.push_str("to;");
     #[cfg(all(feature = "polars", not(feature = "lite")))]
-    enabled_features.push_str("polars;");
+    enabled_features.push_str(format!("polars-{};", polars::VERSION).as_str());
     #[cfg(feature = "self_update")]
     enabled_features.push_str("self_update");
     enabled_features.push('-');
@@ -344,12 +350,9 @@ macro_rules! update_cache_info {
         use cached::Cached;
         use indicatif::HumanCount;
 
-        let cache_instance = $cache_instance.lock();
-        #[allow(clippy::significant_drop_tightening)]
-        match cache_instance {
+        match $cache_instance.lock() {
             Ok(cache) => {
-                let cache_size = cache.cache_size();
-                if cache_size > 0 {
+                if cache.cache_size() > 0 {
                     let hits = cache.cache_hits().unwrap_or_default();
                     let misses = cache.cache_misses().unwrap_or(1);
                     let hit_ratio = (hits as f64 / (hits + misses) as f64) * 100.0;
@@ -748,7 +751,9 @@ pub fn qsv_check_for_update(check_only: bool, no_confirm: bool) -> Result<bool,
 
     let mut updated = false;
     let Ok(latest_release_sv) = semver::Version::parse(latest_release) else {
-        return fail!(format!("Can't parse latest release version: {latest_release}"));
+        return fail!(format!(
+            "Can't parse latest release version: {latest_release}"
+        ));
     };
     let Ok(curr_version_sv) = semver::Version::parse(curr_version) else {
         return fail!(format!("Can't parse current version: {curr_version}"));
@@ -928,9 +933,10 @@ pub fn safe_header_names(
     conditional: bool,
     reserved_names: Option<Vec<String>>,
     unsafe_prefix: &str,
+    keep_case: bool,
 ) -> (Vec<String>, u16) {
     // Create "safe" var/key names - to support dynfmt/url-template, valid python vars & db-safe
-    // column names. Fold to lowercase. Trim leading & trailing whitespace.
+    // column names. Fold to lowercase if keep_case is false. Trim leading & trailing whitespace.
     // Replace whitespace/non-alphanumeric) with _. If name starts with a number & check_first_char
     // is true, prepend the unsafe_prefix. If a column with the same name already exists,
     // append a sequence suffix (e.g. _n). Names are limited to 60 characters in length.
@@ -948,10 +954,14 @@ pub fn safe_header_names(
 
     for header_name in headers {
         let reserved_found = if let Some(reserved_names_vec) = reserved_names.clone() {
-            let lower_header_name = header_name.to_lowercase();
+            let header_name = if keep_case {
+                header_name.to_string()
+            } else {
+                header_name.to_lowercase()
+            };
             reserved_names_vec
                 .iter()
-                .any(|reserved_name| reserved_name == lower_header_name.as_str())
+                .any(|reserved_name| reserved_name == header_name.as_str())
         } else {
             false
         };
@@ -981,7 +991,13 @@ pub fn safe_header_names(
                 .map(char::len_utf8)
                 .take(60)
                 .sum()]
-                .to_lowercase();
+                .to_string();
+
+            final_candidate = if keep_case {
+                final_candidate
+            } else {
+                final_candidate.to_lowercase()
+            };
 
             if prefix != "_" && final_candidate.starts_with('_') {
                 final_candidate = format!("{prefix}{final_candidate}");
@@ -1398,62 +1414,72 @@ pub fn isutf8_file(path: &Path) -> Result<bool, CliError> {
 ///
 /// If the input is empty, try to copy stdin to a file named stdin in the passed temp directory
 /// If the input is empty and stdin is empty, return an error
-/// If it's not empty, check the input files if they exist
+/// If it's not empty, check the input files if they exist, and return an error if they don't
 ///
 /// If the input is a directory, add all the files in the directory to the input
 /// If the input is a file, add the file to the input
 /// If the input are snappy compressed files, uncompress them before adding them to the input
-#[cfg(any(feature = "to", feature = "polars"))]
 pub fn process_input(
-    arg_input: Vec<PathBuf>,
+    mut arg_input: Vec<PathBuf>,
     tmpdir: &tempfile::TempDir,
     empty_stdin_errmsg: &str,
 ) -> Result<Vec<PathBuf>, CliError> {
     let mut processed_input = Vec::with_capacity(arg_input.len());
 
+    // if the input is empty or "-", its stdin. try to copy stdin to a file named
+    // "stdin" in the passed temp directory
     if arg_input.is_empty() || arg_input[0] == PathBuf::from("-") {
         // copy stdin to a file named stdin in a temp directory
         let tmp_filename = tmpdir.path().join("stdin");
         let mut tmp_file = std::fs::File::create(&tmp_filename)?;
-        let nbytes = std::io::copy(&mut std::io::stdin(), &mut tmp_file)?;
-        if nbytes == 0 {
-            return fail_clierror!("{empty_stdin_errmsg}");
-        }
+        std::io::copy(&mut std::io::stdin(), &mut tmp_file)?;
         tmp_file.flush()?;
         processed_input.push(tmp_filename);
-    } else {
-        let mut work_input = Vec::with_capacity(arg_input.len());
+        // remove the "-" from the input
+        // if the input was empty, this does nothing
+        arg_input.remove(0);
+    }
 
-        // is the input a directory?
-        if arg_input.len() == 1 && arg_input[0].is_dir() {
-            // if so, add all the files in the directory to the input
-            let dir = std::fs::read_dir(arg_input[0].clone())?;
-            for entry in dir {
-                let entry = entry?;
-                let path = entry.path();
-                if path.is_file() {
-                    work_input.push(path);
-                }
-            }
-        } else {
-            work_input = arg_input;
+    let work_input = if arg_input.len() == 1 && arg_input[0].is_dir() {
+        // if the input is a directory, add all the files in the directory to the input
+        std::fs::read_dir(&arg_input[0])?
+            .map(|entry| entry.map(|e| e.path()))
+            .collect::<Result<Vec<_>, _>>()?
+    } else {
+        arg_input
+    };
+
+    // check the input files
+    for path in work_input {
+        // does the input file exist?
+        if !path.exists() {
+            return fail_clierror!("Input file '{}' does not exist", path.display());
         }
 
-        // check the input files
-        for path in work_input {
-            // does the input file exist?
-            if !path.exists() {
-                return fail_clierror!("Input file '{}' does not exist", path.display());
-            }
-            // is the input file snappy compressed?
-            if path.extension().unwrap_or_default() == "sz" {
-                // if so, decompress the file
-                let decompressed_filepath = decompress_snappy_file(&path, tmpdir)?;
-                processed_input.push(PathBuf::from(decompressed_filepath));
-            } else {
-                processed_input.push(path.clone());
-            }
+        // is the input file snappy compressed?
+        if path.extension().and_then(std::ffi::OsStr::to_str) == Some("sz") {
+            // if so, decompress the file
+            let decompressed_filepath = decompress_snappy_file(&path, tmpdir)?;
+
+            // rename the decompressed file to the original filename, but still
+            // inside the temp directory. this is so that the decompressed file can be
+            // processed as if it was the original file without the "sz" extension
+            let original_filepath = path.with_extension("");
+            // safety: we know the path has a filename
+            let original_filename = original_filepath.file_name().unwrap();
+
+            let final_decompressed_filepath = tmpdir.path().join(original_filename);
+            std::fs::rename(&decompressed_filepath, &final_decompressed_filepath)?;
+
+            processed_input.push(final_decompressed_filepath);
+        } else {
+            processed_input.push(path);
         }
     }
+
+    if processed_input.is_empty() {
+        return fail_clierror!("{empty_stdin_errmsg}");
+    }
+    log::debug!("processed input: {:?}", processed_input);
     Ok(processed_input)
 }
